pub enum Halloc {
Low = 0,
High = 1,
}Expand description
Enable Handler Allocation
Value on reset: 0
Variants
Low = 0
0: All incoming handler code fetches are not allocated a cache line if a miss occurs
High = 1
1: Handler code access is treated like any other code access arriving at its interface